oldValue property
JSON-encoded form of the previously emitted value, or null if this
was the first emission.
Implementation
final String? oldValue;
JSON-encoded form of the previously emitted value, or null if this
was the first emission.
final String? oldValue;