EventLogAddedEventDto class final
Event payload pushed when a new event-log entry is recorded.
- Annotations
-
- @JsonSerializable.new()
Constructors
- EventLogAddedEventDto({required String streamId, required EventLogDto eventLog})
-
Creates an event-added payload for
streamIdcarryingeventLog. -
EventLogAddedEventDto.fromJson(Map<
String, dynamic> json) -
Deserialises an EventLogAddedEventDto from JSON.
factory
Properties
- eventLog → EventLogDto
-
The new event-log entry.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- streamId → String
-
Identifier of the stream the new event belongs to.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Serialises this DTO to JSON.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited