eventAdded constant
String
const eventAdded
Event name pushed when a new event log entry is recorded.
Implementation
static const String eventAdded = 'ext.rxdart.eventAdded';
Event name pushed when a new event log entry is recorded.
static const String eventAdded = 'ext.rxdart.eventAdded';