InjectErrorRequestDto class

Request payload for the ext.rxdart.injectError service extension — pushes an error onto a tracked subject.

Annotations
  • @JsonSerializable.new()

Constructors

InjectErrorRequestDto({required String identifier, required String message})
Creates an inject-error request targeting identifier with message.
InjectErrorRequestDto.fromJson(Map<String, dynamic> json)
Deserialises an InjectErrorRequestDto from JSON.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
identifier String
Identifier of the tracked subject to inject the error into.
final
message String
Error message that will be forwarded to subject.addError(...).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serialises this DTO to JSON.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited