ListEventLogsResponseDto class
Response payload for the ext.rxdart.listEventLogs service extension.
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
ListEventLogsResponseDto({required List<
EventLogDto> eventLogs}) -
Creates a response with the given list of
eventLogs. -
ListEventLogsResponseDto.fromJson(Map<
String, dynamic> json) -
Deserialises a ListEventLogsResponseDto from JSON.
factory
Properties
-
eventLogs
→ List<
EventLogDto> -
Event-log entries that matched the request.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Serialises this DTO to JSON.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited