RegistryConstants class abstract final

Service-extension method names for the registry feature.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

clearAll → const String
Method name for clearing all currently-registered streams.
inject → const String
Method name for injecting a parsed value into a tracked subject.
injectError → const String
Method name for injecting an error into a tracked subject.