StreamEventDto class

Minimal payload identifying which stream emitted an event.

Annotations
  • @JsonSerializable.new()

Constructors

StreamEventDto({required String streamId})
Creates an event payload targeting streamId.
StreamEventDto.fromJson(Map<String, dynamic> json)
Deserialises a StreamEventDto from JSON.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
streamId String
Identifier of the stream the event applies to.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serialises this DTO to JSON.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited