StreamsConstants class abstract final

Service-extension method and event names for the streams feature.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

listStreamEntries → const String
Method name for listing currently-tracked stream entries.
streamClosed → const String
Event name pushed when a tracked stream completes / closes.
streamErrored → const String
Event name pushed when a tracked stream emits an error.
streamRegistered → const String
Event name pushed when a new stream is registered with the runtime.
streamUpdated → const String
Event name pushed when a tracked stream emits a new value.