ListStreamEntriesResponseDto class
Response payload for the ext.rxdart.listStreamEntries service extension.
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
ListStreamEntriesResponseDto({required List<
StreamEntryDto> entries}) -
Creates a response with the given list of
entries. -
ListStreamEntriesResponseDto.fromJson(Map<
String, dynamic> json) -
Deserialises a ListStreamEntriesResponseDto from JSON.
factory
Properties
-
entries
→ List<
StreamEntryDto> -
Snapshot for each currently-tracked stream.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Serialises this DTO to JSON.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited