StreamEntryDto class

Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

StreamEntryDto({required String id, required String name, required String typeLabel, required String? lastValue, required String? lastError, required int listenerCount, required String? lastEmittedAt, required bool isClosed, required String? closedAt, required bool isInjectable, required bool isSubject})
StreamEntryDto.fromEntry(StreamEntry entry)
factory
StreamEntryDto.fromJson(Map<String, dynamic> json)
factory

Properties

closedAt String?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
isClosed bool
final
isInjectable bool
final
isSubject bool
final
lastEmittedAt String?
final
lastError String?
final
lastValue String?
final
listenerCount int
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
typeLabel String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited