StreamUpdatedEventDto class
Event payload pushed when a tracked stream's snapshot changes.
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- StreamUpdatedEventDto({required String streamId, required StreamEntryDto entry})
-
Creates an update event for
streamIdwith the newentrysnapshot. -
StreamUpdatedEventDto.fromJson(Map<
String, dynamic> json) -
Deserialises a StreamUpdatedEventDto from JSON.
factory
Properties
- entry → StreamEntryDto
-
New snapshot of the stream's state.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- streamId → String
-
Identifier of the stream that updated.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Serialises this DTO to JSON.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited