TrackedSubject<T, S extends Subject<T> > class
Constructors
- TrackedSubject(S _subject, StreamIdentifier? identifier)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- identifier → StreamIdentifier?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
asSubject(
) → S -
enableInjection(
{required T? parse(String raw)}) → TrackedSubject< T, S> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited